@@ -254,4 +254,9 @@ supported_recurrences = {
     'first-wednesday': MonthlyRecurrence(week=1, day='Wednesday'),
     'first-thursday': MonthlyRecurrence(week=1, day='Thursday'),
     'first-friday': MonthlyRecurrence(week=1, day='Friday'),
+    'third-monday': MonthlyRecurrence(week=3, day='Monday'),
+    'third-tuesday': MonthlyRecurrence(week=3, day='Tuesday'),
+    'third-wednesday': MonthlyRecurrence(week=3, day='Wednesday'),
+    'third-thursday': MonthlyRecurrence(week=3, day='Thursday'),
+    'third-friday': MonthlyRecurrence(week=3, day='Friday'),
 }
