@@ -98,6 +98,13 @@ class RecurrenceTestCase(unittest.TestCase):
             self.next_meeting(rec),
         )
 
+    def test_monthly_third_week(self):
+        rec = recurrence.MonthlyRecurrence(week=3, day='Thursday')
+        self.assertEqual(
+            datetime.datetime(2014, 11, 19, 2, 47, 28, 832666),
+            self.next_meeting(rec),
+        )
+
     def test_monthly_invalid_week(self):
         rec = recurrence.MonthlyRecurrence(week=6, day='Wednesday')
         self.assertRaises(
